# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from . import _utilities
from . import outputs
from ._inputs import *

__all__ = ['CleanRoomsCleanRoomArgs', 'CleanRoomsCleanRoom']

@pulumi.input_type
class CleanRoomsCleanRoomArgs:
    def __init__(__self__, *,
                 comment: Optional[pulumi.Input[_builtins.str]] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 owner: Optional[pulumi.Input[_builtins.str]] = None,
                 remote_detailed_info: Optional[pulumi.Input['CleanRoomsCleanRoomRemoteDetailedInfoArgs']] = None,
                 workspace_id: Optional[pulumi.Input[_builtins.str]] = None):
        """
        The set of arguments for constructing a CleanRoomsCleanRoom resource.
        :param pulumi.Input[_builtins.str] name: The name of the clean room.
               It should follow [UC securable naming requirements](https://docs.databricks.com/en/data-governance/unity-catalog/index.html#securable-object-naming-requirements)
        :param pulumi.Input[_builtins.str] owner: This is the Databricks username of the owner of the local clean room securable for permission management
        :param pulumi.Input['CleanRoomsCleanRoomRemoteDetailedInfoArgs'] remote_detailed_info: Central clean room details. During creation, users need to specify
               cloud_vendor, region, and collaborators.global_metastore_id.
               This field will not be filled in the ListCleanRooms call
        :param pulumi.Input[_builtins.str] workspace_id: Workspace ID of the resource
        """
        if comment is not None:
            pulumi.set(__self__, "comment", comment)
        if name is not None:
            pulumi.set(__self__, "name", name)
        if owner is not None:
            pulumi.set(__self__, "owner", owner)
        if remote_detailed_info is not None:
            pulumi.set(__self__, "remote_detailed_info", remote_detailed_info)
        if workspace_id is not None:
            pulumi.set(__self__, "workspace_id", workspace_id)

    @_builtins.property
    @pulumi.getter
    def comment(self) -> Optional[pulumi.Input[_builtins.str]]:
        return pulumi.get(self, "comment")

    @comment.setter
    def comment(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "comment", value)

    @_builtins.property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The name of the clean room.
        It should follow [UC securable naming requirements](https://docs.databricks.com/en/data-governance/unity-catalog/index.html#securable-object-naming-requirements)
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "name", value)

    @_builtins.property
    @pulumi.getter
    def owner(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        This is the Databricks username of the owner of the local clean room securable for permission management
        """
        return pulumi.get(self, "owner")

    @owner.setter
    def owner(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "owner", value)

    @_builtins.property
    @pulumi.getter(name="remoteDetailedInfo")
    def remote_detailed_info(self) -> Optional[pulumi.Input['CleanRoomsCleanRoomRemoteDetailedInfoArgs']]:
        """
        Central clean room details. During creation, users need to specify
        cloud_vendor, region, and collaborators.global_metastore_id.
        This field will not be filled in the ListCleanRooms call
        """
        return pulumi.get(self, "remote_detailed_info")

    @remote_detailed_info.setter
    def remote_detailed_info(self, value: Optional[pulumi.Input['CleanRoomsCleanRoomRemoteDetailedInfoArgs']]):
        pulumi.set(self, "remote_detailed_info", value)

    @_builtins.property
    @pulumi.getter(name="workspaceId")
    def workspace_id(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Workspace ID of the resource
        """
        return pulumi.get(self, "workspace_id")

    @workspace_id.setter
    def workspace_id(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "workspace_id", value)


@pulumi.input_type
class _CleanRoomsCleanRoomState:
    def __init__(__self__, *,
                 access_restricted: Optional[pulumi.Input[_builtins.str]] = None,
                 comment: Optional[pulumi.Input[_builtins.str]] = None,
                 created_at: Optional[pulumi.Input[_builtins.int]] = None,
                 local_collaborator_alias: Optional[pulumi.Input[_builtins.str]] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 output_catalog: Optional[pulumi.Input['CleanRoomsCleanRoomOutputCatalogArgs']] = None,
                 owner: Optional[pulumi.Input[_builtins.str]] = None,
                 remote_detailed_info: Optional[pulumi.Input['CleanRoomsCleanRoomRemoteDetailedInfoArgs']] = None,
                 status: Optional[pulumi.Input[_builtins.str]] = None,
                 updated_at: Optional[pulumi.Input[_builtins.int]] = None,
                 workspace_id: Optional[pulumi.Input[_builtins.str]] = None):
        """
        Input properties used for looking up and filtering CleanRoomsCleanRoom resources.
        :param pulumi.Input[_builtins.str] access_restricted: (string) - Whether clean room access is restricted due to [CSP](https://docs.databricks.com/en/security/privacy/security-profile.html). Possible values are: `CSP_MISMATCH`, `NO_RESTRICTION`
        :param pulumi.Input[_builtins.int] created_at: (integer) - When the clean room was created, in epoch milliseconds
        :param pulumi.Input[_builtins.str] local_collaborator_alias: (string) - The alias of the collaborator tied to the local clean room
        :param pulumi.Input[_builtins.str] name: The name of the clean room.
               It should follow [UC securable naming requirements](https://docs.databricks.com/en/data-governance/unity-catalog/index.html#securable-object-naming-requirements)
        :param pulumi.Input['CleanRoomsCleanRoomOutputCatalogArgs'] output_catalog: (CleanRoomOutputCatalog) - Output catalog of the clean room. It is an output only field. Output catalog is manipulated
               using the separate CreateCleanRoomOutputCatalog API
        :param pulumi.Input[_builtins.str] owner: This is the Databricks username of the owner of the local clean room securable for permission management
        :param pulumi.Input['CleanRoomsCleanRoomRemoteDetailedInfoArgs'] remote_detailed_info: Central clean room details. During creation, users need to specify
               cloud_vendor, region, and collaborators.global_metastore_id.
               This field will not be filled in the ListCleanRooms call
        :param pulumi.Input[_builtins.str] status: (string) - . Possible values are: `CREATED`, `NOT_CREATED`, `NOT_ELIGIBLE`
        :param pulumi.Input[_builtins.int] updated_at: (integer) - When the clean room was last updated, in epoch milliseconds
        :param pulumi.Input[_builtins.str] workspace_id: Workspace ID of the resource
        """
        if access_restricted is not None:
            pulumi.set(__self__, "access_restricted", access_restricted)
        if comment is not None:
            pulumi.set(__self__, "comment", comment)
        if created_at is not None:
            pulumi.set(__self__, "created_at", created_at)
        if local_collaborator_alias is not None:
            pulumi.set(__self__, "local_collaborator_alias", local_collaborator_alias)
        if name is not None:
            pulumi.set(__self__, "name", name)
        if output_catalog is not None:
            pulumi.set(__self__, "output_catalog", output_catalog)
        if owner is not None:
            pulumi.set(__self__, "owner", owner)
        if remote_detailed_info is not None:
            pulumi.set(__self__, "remote_detailed_info", remote_detailed_info)
        if status is not None:
            pulumi.set(__self__, "status", status)
        if updated_at is not None:
            pulumi.set(__self__, "updated_at", updated_at)
        if workspace_id is not None:
            pulumi.set(__self__, "workspace_id", workspace_id)

    @_builtins.property
    @pulumi.getter(name="accessRestricted")
    def access_restricted(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        (string) - Whether clean room access is restricted due to [CSP](https://docs.databricks.com/en/security/privacy/security-profile.html). Possible values are: `CSP_MISMATCH`, `NO_RESTRICTION`
        """
        return pulumi.get(self, "access_restricted")

    @access_restricted.setter
    def access_restricted(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "access_restricted", value)

    @_builtins.property
    @pulumi.getter
    def comment(self) -> Optional[pulumi.Input[_builtins.str]]:
        return pulumi.get(self, "comment")

    @comment.setter
    def comment(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "comment", value)

    @_builtins.property
    @pulumi.getter(name="createdAt")
    def created_at(self) -> Optional[pulumi.Input[_builtins.int]]:
        """
        (integer) - When the clean room was created, in epoch milliseconds
        """
        return pulumi.get(self, "created_at")

    @created_at.setter
    def created_at(self, value: Optional[pulumi.Input[_builtins.int]]):
        pulumi.set(self, "created_at", value)

    @_builtins.property
    @pulumi.getter(name="localCollaboratorAlias")
    def local_collaborator_alias(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        (string) - The alias of the collaborator tied to the local clean room
        """
        return pulumi.get(self, "local_collaborator_alias")

    @local_collaborator_alias.setter
    def local_collaborator_alias(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "local_collaborator_alias", value)

    @_builtins.property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The name of the clean room.
        It should follow [UC securable naming requirements](https://docs.databricks.com/en/data-governance/unity-catalog/index.html#securable-object-naming-requirements)
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "name", value)

    @_builtins.property
    @pulumi.getter(name="outputCatalog")
    def output_catalog(self) -> Optional[pulumi.Input['CleanRoomsCleanRoomOutputCatalogArgs']]:
        """
        (CleanRoomOutputCatalog) - Output catalog of the clean room. It is an output only field. Output catalog is manipulated
        using the separate CreateCleanRoomOutputCatalog API
        """
        return pulumi.get(self, "output_catalog")

    @output_catalog.setter
    def output_catalog(self, value: Optional[pulumi.Input['CleanRoomsCleanRoomOutputCatalogArgs']]):
        pulumi.set(self, "output_catalog", value)

    @_builtins.property
    @pulumi.getter
    def owner(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        This is the Databricks username of the owner of the local clean room securable for permission management
        """
        return pulumi.get(self, "owner")

    @owner.setter
    def owner(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "owner", value)

    @_builtins.property
    @pulumi.getter(name="remoteDetailedInfo")
    def remote_detailed_info(self) -> Optional[pulumi.Input['CleanRoomsCleanRoomRemoteDetailedInfoArgs']]:
        """
        Central clean room details. During creation, users need to specify
        cloud_vendor, region, and collaborators.global_metastore_id.
        This field will not be filled in the ListCleanRooms call
        """
        return pulumi.get(self, "remote_detailed_info")

    @remote_detailed_info.setter
    def remote_detailed_info(self, value: Optional[pulumi.Input['CleanRoomsCleanRoomRemoteDetailedInfoArgs']]):
        pulumi.set(self, "remote_detailed_info", value)

    @_builtins.property
    @pulumi.getter
    def status(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        (string) - . Possible values are: `CREATED`, `NOT_CREATED`, `NOT_ELIGIBLE`
        """
        return pulumi.get(self, "status")

    @status.setter
    def status(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "status", value)

    @_builtins.property
    @pulumi.getter(name="updatedAt")
    def updated_at(self) -> Optional[pulumi.Input[_builtins.int]]:
        """
        (integer) - When the clean room was last updated, in epoch milliseconds
        """
        return pulumi.get(self, "updated_at")

    @updated_at.setter
    def updated_at(self, value: Optional[pulumi.Input[_builtins.int]]):
        pulumi.set(self, "updated_at", value)

    @_builtins.property
    @pulumi.getter(name="workspaceId")
    def workspace_id(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Workspace ID of the resource
        """
        return pulumi.get(self, "workspace_id")

    @workspace_id.setter
    def workspace_id(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "workspace_id", value)


@pulumi.type_token("databricks:index/cleanRoomsCleanRoom:CleanRoomsCleanRoom")
class CleanRoomsCleanRoom(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 comment: Optional[pulumi.Input[_builtins.str]] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 owner: Optional[pulumi.Input[_builtins.str]] = None,
                 remote_detailed_info: Optional[pulumi.Input[Union['CleanRoomsCleanRoomRemoteDetailedInfoArgs', 'CleanRoomsCleanRoomRemoteDetailedInfoArgsDict']]] = None,
                 workspace_id: Optional[pulumi.Input[_builtins.str]] = None,
                 __props__=None):
        """
        A Clean Room is a secure environment for data collaboration that enables multiple organizations to analyze their data together while maintaining privacy and security. Clean Rooms provide a controlled environment where data can be shared and analyzed without exposing the underlying raw data.

        ## Example Usage

        ## Import

        As of Pulumi v1.5, resources can be imported through configuration.

        hcl

        import {

          id = "name"

          to = databricks_clean_rooms_clean_room.this

        }

        If you are using an older version of Pulumi, import the resource using the `pulumi import` command as follows:

        ```sh
        $ pulumi import databricks:index/cleanRoomsCleanRoom:CleanRoomsCleanRoom databricks_clean_rooms_clean_room "name"
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[_builtins.str] name: The name of the clean room.
               It should follow [UC securable naming requirements](https://docs.databricks.com/en/data-governance/unity-catalog/index.html#securable-object-naming-requirements)
        :param pulumi.Input[_builtins.str] owner: This is the Databricks username of the owner of the local clean room securable for permission management
        :param pulumi.Input[Union['CleanRoomsCleanRoomRemoteDetailedInfoArgs', 'CleanRoomsCleanRoomRemoteDetailedInfoArgsDict']] remote_detailed_info: Central clean room details. During creation, users need to specify
               cloud_vendor, region, and collaborators.global_metastore_id.
               This field will not be filled in the ListCleanRooms call
        :param pulumi.Input[_builtins.str] workspace_id: Workspace ID of the resource
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: Optional[CleanRoomsCleanRoomArgs] = None,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        A Clean Room is a secure environment for data collaboration that enables multiple organizations to analyze their data together while maintaining privacy and security. Clean Rooms provide a controlled environment where data can be shared and analyzed without exposing the underlying raw data.

        ## Example Usage

        ## Import

        As of Pulumi v1.5, resources can be imported through configuration.

        hcl

        import {

          id = "name"

          to = databricks_clean_rooms_clean_room.this

        }

        If you are using an older version of Pulumi, import the resource using the `pulumi import` command as follows:

        ```sh
        $ pulumi import databricks:index/cleanRoomsCleanRoom:CleanRoomsCleanRoom databricks_clean_rooms_clean_room "name"
        ```

        :param str resource_name: The name of the resource.
        :param CleanRoomsCleanRoomArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(CleanRoomsCleanRoomArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 comment: Optional[pulumi.Input[_builtins.str]] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 owner: Optional[pulumi.Input[_builtins.str]] = None,
                 remote_detailed_info: Optional[pulumi.Input[Union['CleanRoomsCleanRoomRemoteDetailedInfoArgs', 'CleanRoomsCleanRoomRemoteDetailedInfoArgsDict']]] = None,
                 workspace_id: Optional[pulumi.Input[_builtins.str]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = CleanRoomsCleanRoomArgs.__new__(CleanRoomsCleanRoomArgs)

            __props__.__dict__["comment"] = comment
            __props__.__dict__["name"] = name
            __props__.__dict__["owner"] = owner
            __props__.__dict__["remote_detailed_info"] = remote_detailed_info
            __props__.__dict__["workspace_id"] = workspace_id
            __props__.__dict__["access_restricted"] = None
            __props__.__dict__["created_at"] = None
            __props__.__dict__["local_collaborator_alias"] = None
            __props__.__dict__["output_catalog"] = None
            __props__.__dict__["status"] = None
            __props__.__dict__["updated_at"] = None
        super(CleanRoomsCleanRoom, __self__).__init__(
            'databricks:index/cleanRoomsCleanRoom:CleanRoomsCleanRoom',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            access_restricted: Optional[pulumi.Input[_builtins.str]] = None,
            comment: Optional[pulumi.Input[_builtins.str]] = None,
            created_at: Optional[pulumi.Input[_builtins.int]] = None,
            local_collaborator_alias: Optional[pulumi.Input[_builtins.str]] = None,
            name: Optional[pulumi.Input[_builtins.str]] = None,
            output_catalog: Optional[pulumi.Input[Union['CleanRoomsCleanRoomOutputCatalogArgs', 'CleanRoomsCleanRoomOutputCatalogArgsDict']]] = None,
            owner: Optional[pulumi.Input[_builtins.str]] = None,
            remote_detailed_info: Optional[pulumi.Input[Union['CleanRoomsCleanRoomRemoteDetailedInfoArgs', 'CleanRoomsCleanRoomRemoteDetailedInfoArgsDict']]] = None,
            status: Optional[pulumi.Input[_builtins.str]] = None,
            updated_at: Optional[pulumi.Input[_builtins.int]] = None,
            workspace_id: Optional[pulumi.Input[_builtins.str]] = None) -> 'CleanRoomsCleanRoom':
        """
        Get an existing CleanRoomsCleanRoom resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[_builtins.str] access_restricted: (string) - Whether clean room access is restricted due to [CSP](https://docs.databricks.com/en/security/privacy/security-profile.html). Possible values are: `CSP_MISMATCH`, `NO_RESTRICTION`
        :param pulumi.Input[_builtins.int] created_at: (integer) - When the clean room was created, in epoch milliseconds
        :param pulumi.Input[_builtins.str] local_collaborator_alias: (string) - The alias of the collaborator tied to the local clean room
        :param pulumi.Input[_builtins.str] name: The name of the clean room.
               It should follow [UC securable naming requirements](https://docs.databricks.com/en/data-governance/unity-catalog/index.html#securable-object-naming-requirements)
        :param pulumi.Input[Union['CleanRoomsCleanRoomOutputCatalogArgs', 'CleanRoomsCleanRoomOutputCatalogArgsDict']] output_catalog: (CleanRoomOutputCatalog) - Output catalog of the clean room. It is an output only field. Output catalog is manipulated
               using the separate CreateCleanRoomOutputCatalog API
        :param pulumi.Input[_builtins.str] owner: This is the Databricks username of the owner of the local clean room securable for permission management
        :param pulumi.Input[Union['CleanRoomsCleanRoomRemoteDetailedInfoArgs', 'CleanRoomsCleanRoomRemoteDetailedInfoArgsDict']] remote_detailed_info: Central clean room details. During creation, users need to specify
               cloud_vendor, region, and collaborators.global_metastore_id.
               This field will not be filled in the ListCleanRooms call
        :param pulumi.Input[_builtins.str] status: (string) - . Possible values are: `CREATED`, `NOT_CREATED`, `NOT_ELIGIBLE`
        :param pulumi.Input[_builtins.int] updated_at: (integer) - When the clean room was last updated, in epoch milliseconds
        :param pulumi.Input[_builtins.str] workspace_id: Workspace ID of the resource
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _CleanRoomsCleanRoomState.__new__(_CleanRoomsCleanRoomState)

        __props__.__dict__["access_restricted"] = access_restricted
        __props__.__dict__["comment"] = comment
        __props__.__dict__["created_at"] = created_at
        __props__.__dict__["local_collaborator_alias"] = local_collaborator_alias
        __props__.__dict__["name"] = name
        __props__.__dict__["output_catalog"] = output_catalog
        __props__.__dict__["owner"] = owner
        __props__.__dict__["remote_detailed_info"] = remote_detailed_info
        __props__.__dict__["status"] = status
        __props__.__dict__["updated_at"] = updated_at
        __props__.__dict__["workspace_id"] = workspace_id
        return CleanRoomsCleanRoom(resource_name, opts=opts, __props__=__props__)

    @_builtins.property
    @pulumi.getter(name="accessRestricted")
    def access_restricted(self) -> pulumi.Output[_builtins.str]:
        """
        (string) - Whether clean room access is restricted due to [CSP](https://docs.databricks.com/en/security/privacy/security-profile.html). Possible values are: `CSP_MISMATCH`, `NO_RESTRICTION`
        """
        return pulumi.get(self, "access_restricted")

    @_builtins.property
    @pulumi.getter
    def comment(self) -> pulumi.Output[Optional[_builtins.str]]:
        return pulumi.get(self, "comment")

    @_builtins.property
    @pulumi.getter(name="createdAt")
    def created_at(self) -> pulumi.Output[_builtins.int]:
        """
        (integer) - When the clean room was created, in epoch milliseconds
        """
        return pulumi.get(self, "created_at")

    @_builtins.property
    @pulumi.getter(name="localCollaboratorAlias")
    def local_collaborator_alias(self) -> pulumi.Output[_builtins.str]:
        """
        (string) - The alias of the collaborator tied to the local clean room
        """
        return pulumi.get(self, "local_collaborator_alias")

    @_builtins.property
    @pulumi.getter
    def name(self) -> pulumi.Output[_builtins.str]:
        """
        The name of the clean room.
        It should follow [UC securable naming requirements](https://docs.databricks.com/en/data-governance/unity-catalog/index.html#securable-object-naming-requirements)
        """
        return pulumi.get(self, "name")

    @_builtins.property
    @pulumi.getter(name="outputCatalog")
    def output_catalog(self) -> pulumi.Output['outputs.CleanRoomsCleanRoomOutputCatalog']:
        """
        (CleanRoomOutputCatalog) - Output catalog of the clean room. It is an output only field. Output catalog is manipulated
        using the separate CreateCleanRoomOutputCatalog API
        """
        return pulumi.get(self, "output_catalog")

    @_builtins.property
    @pulumi.getter
    def owner(self) -> pulumi.Output[Optional[_builtins.str]]:
        """
        This is the Databricks username of the owner of the local clean room securable for permission management
        """
        return pulumi.get(self, "owner")

    @_builtins.property
    @pulumi.getter(name="remoteDetailedInfo")
    def remote_detailed_info(self) -> pulumi.Output[Optional['outputs.CleanRoomsCleanRoomRemoteDetailedInfo']]:
        """
        Central clean room details. During creation, users need to specify
        cloud_vendor, region, and collaborators.global_metastore_id.
        This field will not be filled in the ListCleanRooms call
        """
        return pulumi.get(self, "remote_detailed_info")

    @_builtins.property
    @pulumi.getter
    def status(self) -> pulumi.Output[_builtins.str]:
        """
        (string) - . Possible values are: `CREATED`, `NOT_CREATED`, `NOT_ELIGIBLE`
        """
        return pulumi.get(self, "status")

    @_builtins.property
    @pulumi.getter(name="updatedAt")
    def updated_at(self) -> pulumi.Output[_builtins.int]:
        """
        (integer) - When the clean room was last updated, in epoch milliseconds
        """
        return pulumi.get(self, "updated_at")

    @_builtins.property
    @pulumi.getter(name="workspaceId")
    def workspace_id(self) -> pulumi.Output[Optional[_builtins.str]]:
        """
        Workspace ID of the resource
        """
        return pulumi.get(self, "workspace_id")




# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from . import _utilities
from . import outputs

__all__ = [
    'GetDatabaseSyncedDatabaseTablesResult',
    'AwaitableGetDatabaseSyncedDatabaseTablesResult',
    'get_database_synced_database_tables',
    'get_database_synced_database_tables_output',
]

@pulumi.output_type
class GetDatabaseSyncedDatabaseTablesResult:
    """
    A collection of values returned by getDatabaseSyncedDatabaseTables.
    """
    def __init__(__self__, id=None, synced_tables=None, workspace_id=None):
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if synced_tables and not isinstance(synced_tables, list):
            raise TypeError("Expected argument 'synced_tables' to be a list")
        pulumi.set(__self__, "synced_tables", synced_tables)
        if workspace_id and not isinstance(workspace_id, str):
            raise TypeError("Expected argument 'workspace_id' to be a str")
        pulumi.set(__self__, "workspace_id", workspace_id)

    @_builtins.property
    @pulumi.getter
    def id(self) -> _builtins.str:
        """
        The provider-assigned unique ID for this managed resource.
        """
        return pulumi.get(self, "id")

    @_builtins.property
    @pulumi.getter(name="syncedTables")
    def synced_tables(self) -> Sequence['outputs.GetDatabaseSyncedDatabaseTablesSyncedTableResult']:
        return pulumi.get(self, "synced_tables")

    @_builtins.property
    @pulumi.getter(name="workspaceId")
    def workspace_id(self) -> Optional[_builtins.str]:
        return pulumi.get(self, "workspace_id")


class AwaitableGetDatabaseSyncedDatabaseTablesResult(GetDatabaseSyncedDatabaseTablesResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetDatabaseSyncedDatabaseTablesResult(
            id=self.id,
            synced_tables=self.synced_tables,
            workspace_id=self.workspace_id)


def get_database_synced_database_tables(workspace_id: Optional[_builtins.str] = None,
                                        opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetDatabaseSyncedDatabaseTablesResult:
    """
    Use this data source to access information about an existing resource.

    :param _builtins.str workspace_id: Workspace ID of the resource
    """
    __args__ = dict()
    __args__['workspaceId'] = workspace_id
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('databricks:index/getDatabaseSyncedDatabaseTables:getDatabaseSyncedDatabaseTables', __args__, opts=opts, typ=GetDatabaseSyncedDatabaseTablesResult).value

    return AwaitableGetDatabaseSyncedDatabaseTablesResult(
        id=pulumi.get(__ret__, 'id'),
        synced_tables=pulumi.get(__ret__, 'synced_tables'),
        workspace_id=pulumi.get(__ret__, 'workspace_id'))
def get_database_synced_database_tables_output(workspace_id: Optional[pulumi.Input[Optional[_builtins.str]]] = None,
                                               opts: Optional[Union[pulumi.InvokeOptions, pulumi.InvokeOutputOptions]] = None) -> pulumi.Output[GetDatabaseSyncedDatabaseTablesResult]:
    """
    Use this data source to access information about an existing resource.

    :param _builtins.str workspace_id: Workspace ID of the resource
    """
    __args__ = dict()
    __args__['workspaceId'] = workspace_id
    opts = pulumi.InvokeOutputOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke_output('databricks:index/getDatabaseSyncedDatabaseTables:getDatabaseSyncedDatabaseTables', __args__, opts=opts, typ=GetDatabaseSyncedDatabaseTablesResult)
    return __ret__.apply(lambda __response__: GetDatabaseSyncedDatabaseTablesResult(
        id=pulumi.get(__response__, 'id'),
        synced_tables=pulumi.get(__response__, 'synced_tables'),
        workspace_id=pulumi.get(__response__, 'workspace_id')))



# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from . import _utilities
from . import outputs
from ._inputs import *

__all__ = ['ShareArgs', 'Share']

@pulumi.input_type
class ShareArgs:
    def __init__(__self__, *,
                 comment: Optional[pulumi.Input[_builtins.str]] = None,
                 created_at: Optional[pulumi.Input[_builtins.int]] = None,
                 created_by: Optional[pulumi.Input[_builtins.str]] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 objects: Optional[pulumi.Input[Sequence[pulumi.Input['ShareObjectArgs']]]] = None,
                 owner: Optional[pulumi.Input[_builtins.str]] = None,
                 storage_location: Optional[pulumi.Input[_builtins.str]] = None,
                 storage_root: Optional[pulumi.Input[_builtins.str]] = None,
                 updated_at: Optional[pulumi.Input[_builtins.int]] = None,
                 updated_by: Optional[pulumi.Input[_builtins.str]] = None):
        """
        The set of arguments for constructing a Share resource.
        :param pulumi.Input[_builtins.str] comment: User-supplied free-form text.
        :param pulumi.Input[_builtins.int] created_at: Time when the share was created.
        :param pulumi.Input[_builtins.str] created_by: The principal that created the share.
        :param pulumi.Input[_builtins.str] name: Name of share. Change forces creation of a new resource.
        :param pulumi.Input[_builtins.str] owner: User name/group name/sp application_id of the share owner.
        """
        if comment is not None:
            pulumi.set(__self__, "comment", comment)
        if created_at is not None:
            pulumi.set(__self__, "created_at", created_at)
        if created_by is not None:
            pulumi.set(__self__, "created_by", created_by)
        if name is not None:
            pulumi.set(__self__, "name", name)
        if objects is not None:
            pulumi.set(__self__, "objects", objects)
        if owner is not None:
            pulumi.set(__self__, "owner", owner)
        if storage_location is not None:
            pulumi.set(__self__, "storage_location", storage_location)
        if storage_root is not None:
            pulumi.set(__self__, "storage_root", storage_root)
        if updated_at is not None:
            pulumi.set(__self__, "updated_at", updated_at)
        if updated_by is not None:
            pulumi.set(__self__, "updated_by", updated_by)

    @_builtins.property
    @pulumi.getter
    def comment(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        User-supplied free-form text.
        """
        return pulumi.get(self, "comment")

    @comment.setter
    def comment(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "comment", value)

    @_builtins.property
    @pulumi.getter(name="createdAt")
    def created_at(self) -> Optional[pulumi.Input[_builtins.int]]:
        """
        Time when the share was created.
        """
        return pulumi.get(self, "created_at")

    @created_at.setter
    def created_at(self, value: Optional[pulumi.Input[_builtins.int]]):
        pulumi.set(self, "created_at", value)

    @_builtins.property
    @pulumi.getter(name="createdBy")
    def created_by(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The principal that created the share.
        """
        return pulumi.get(self, "created_by")

    @created_by.setter
    def created_by(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "created_by", value)

    @_builtins.property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Name of share. Change forces creation of a new resource.
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "name", value)

    @_builtins.property
    @pulumi.getter
    def objects(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['ShareObjectArgs']]]]:
        return pulumi.get(self, "objects")

    @objects.setter
    def objects(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['ShareObjectArgs']]]]):
        pulumi.set(self, "objects", value)

    @_builtins.property
    @pulumi.getter
    def owner(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        User name/group name/sp application_id of the share owner.
        """
        return pulumi.get(self, "owner")

    @owner.setter
    def owner(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "owner", value)

    @_builtins.property
    @pulumi.getter(name="storageLocation")
    def storage_location(self) -> Optional[pulumi.Input[_builtins.str]]:
        return pulumi.get(self, "storage_location")

    @storage_location.setter
    def storage_location(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "storage_location", value)

    @_builtins.property
    @pulumi.getter(name="storageRoot")
    def storage_root(self) -> Optional[pulumi.Input[_builtins.str]]:
        return pulumi.get(self, "storage_root")

    @storage_root.setter
    def storage_root(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "storage_root", value)

    @_builtins.property
    @pulumi.getter(name="updatedAt")
    def updated_at(self) -> Optional[pulumi.Input[_builtins.int]]:
        return pulumi.get(self, "updated_at")

    @updated_at.setter
    def updated_at(self, value: Optional[pulumi.Input[_builtins.int]]):
        pulumi.set(self, "updated_at", value)

    @_builtins.property
    @pulumi.getter(name="updatedBy")
    def updated_by(self) -> Optional[pulumi.Input[_builtins.str]]:
        return pulumi.get(self, "updated_by")

    @updated_by.setter
    def updated_by(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "updated_by", value)


@pulumi.input_type
class _ShareState:
    def __init__(__self__, *,
                 comment: Optional[pulumi.Input[_builtins.str]] = None,
                 created_at: Optional[pulumi.Input[_builtins.int]] = None,
                 created_by: Optional[pulumi.Input[_builtins.str]] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 objects: Optional[pulumi.Input[Sequence[pulumi.Input['ShareObjectArgs']]]] = None,
                 owner: Optional[pulumi.Input[_builtins.str]] = None,
                 storage_location: Optional[pulumi.Input[_builtins.str]] = None,
                 storage_root: Optional[pulumi.Input[_builtins.str]] = None,
                 updated_at: Optional[pulumi.Input[_builtins.int]] = None,
                 updated_by: Optional[pulumi.Input[_builtins.str]] = None):
        """
        Input properties used for looking up and filtering Share resources.
        :param pulumi.Input[_builtins.str] comment: User-supplied free-form text.
        :param pulumi.Input[_builtins.int] created_at: Time when the share was created.
        :param pulumi.Input[_builtins.str] created_by: The principal that created the share.
        :param pulumi.Input[_builtins.str] name: Name of share. Change forces creation of a new resource.
        :param pulumi.Input[_builtins.str] owner: User name/group name/sp application_id of the share owner.
        """
        if comment is not None:
            pulumi.set(__self__, "comment", comment)
        if created_at is not None:
            pulumi.set(__self__, "created_at", created_at)
        if created_by is not None:
            pulumi.set(__self__, "created_by", created_by)
        if name is not None:
            pulumi.set(__self__, "name", name)
        if objects is not None:
            pulumi.set(__self__, "objects", objects)
        if owner is not None:
            pulumi.set(__self__, "owner", owner)
        if storage_location is not None:
            pulumi.set(__self__, "storage_location", storage_location)
        if storage_root is not None:
            pulumi.set(__self__, "storage_root", storage_root)
        if updated_at is not None:
            pulumi.set(__self__, "updated_at", updated_at)
        if updated_by is not None:
            pulumi.set(__self__, "updated_by", updated_by)

    @_builtins.property
    @pulumi.getter
    def comment(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        User-supplied free-form text.
        """
        return pulumi.get(self, "comment")

    @comment.setter
    def comment(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "comment", value)

    @_builtins.property
    @pulumi.getter(name="createdAt")
    def created_at(self) -> Optional[pulumi.Input[_builtins.int]]:
        """
        Time when the share was created.
        """
        return pulumi.get(self, "created_at")

    @created_at.setter
    def created_at(self, value: Optional[pulumi.Input[_builtins.int]]):
        pulumi.set(self, "created_at", value)

    @_builtins.property
    @pulumi.getter(name="createdBy")
    def created_by(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The principal that created the share.
        """
        return pulumi.get(self, "created_by")

    @created_by.setter
    def created_by(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "created_by", value)

    @_builtins.property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Name of share. Change forces creation of a new resource.
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "name", value)

    @_builtins.property
    @pulumi.getter
    def objects(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['ShareObjectArgs']]]]:
        return pulumi.get(self, "objects")

    @objects.setter
    def objects(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['ShareObjectArgs']]]]):
        pulumi.set(self, "objects", value)

    @_builtins.property
    @pulumi.getter
    def owner(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        User name/group name/sp application_id of the share owner.
        """
        return pulumi.get(self, "owner")

    @owner.setter
    def owner(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "owner", value)

    @_builtins.property
    @pulumi.getter(name="storageLocation")
    def storage_location(self) -> Optional[pulumi.Input[_builtins.str]]:
        return pulumi.get(self, "storage_location")

    @storage_location.setter
    def storage_location(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "storage_location", value)

    @_builtins.property
    @pulumi.getter(name="storageRoot")
    def storage_root(self) -> Optional[pulumi.Input[_builtins.str]]:
        return pulumi.get(self, "storage_root")

    @storage_root.setter
    def storage_root(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "storage_root", value)

    @_builtins.property
    @pulumi.getter(name="updatedAt")
    def updated_at(self) -> Optional[pulumi.Input[_builtins.int]]:
        return pulumi.get(self, "updated_at")

    @updated_at.setter
    def updated_at(self, value: Optional[pulumi.Input[_builtins.int]]):
        pulumi.set(self, "updated_at", value)

    @_builtins.property
    @pulumi.getter(name="updatedBy")
    def updated_by(self) -> Optional[pulumi.Input[_builtins.str]]:
        return pulumi.get(self, "updated_by")

    @updated_by.setter
    def updated_by(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "updated_by", value)


@pulumi.type_token("databricks:index/share:Share")
class Share(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 comment: Optional[pulumi.Input[_builtins.str]] = None,
                 created_at: Optional[pulumi.Input[_builtins.int]] = None,
                 created_by: Optional[pulumi.Input[_builtins.str]] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 objects: Optional[pulumi.Input[Sequence[pulumi.Input[Union['ShareObjectArgs', 'ShareObjectArgsDict']]]]] = None,
                 owner: Optional[pulumi.Input[_builtins.str]] = None,
                 storage_location: Optional[pulumi.Input[_builtins.str]] = None,
                 storage_root: Optional[pulumi.Input[_builtins.str]] = None,
                 updated_at: Optional[pulumi.Input[_builtins.int]] = None,
                 updated_by: Optional[pulumi.Input[_builtins.str]] = None,
                 __props__=None):
        """
        In Delta Sharing, a share is a read-only collection of tables and table partitions that a provider wants to share with one or more recipients. If your recipient uses a Unity Catalog-enabled Databricks workspace, you can also include notebook files, views (including dynamic views that restrict access at the row and column level), Unity Catalog volumes, and Unity Catalog models in a share.

        > This resource can only be used with a workspace-level provider!

        In a Unity Catalog-enabled Databricks workspace, a share is a securable object registered in Unity Catalog. A `Share` is contained within a databricks_metastore. If you remove a share from your Unity Catalog metastore, all recipients of that share lose the ability to access it.

        ## Example Usage

        > In Pulumi configuration, it is recommended to define objects in alphabetical order of their `name` arguments, so that you get consistent and readable diff. Whenever objects are added or removed, or `name` is renamed, you'll observe a change in the majority of tasks. It's related to the fact that the current version of the provider treats `object` blocks as an ordered list. Alternatively, `object` block could have been an unordered set, though end-users would see the entire block replaced upon a change in single property of the task.

        Creating a Delta Sharing share and add some existing tables to it

        ```python
        import pulumi
        import pulumi_databricks as databricks

        things = databricks.get_tables(catalog_name="sandbox",
            schema_name="things")
        some = databricks.Share("some",
            objects=[{"key": k, "value": v} for k, v in things.ids].apply(lambda entries: [{
                "name": entry["value"],
                "dataObjectType": "TABLE",
            } for entry in entries]),
            name="my_share")
        ```

        Creating a Delta Sharing share and add a schema to it(including all current and future tables).

        ```python
        import pulumi
        import pulumi_databricks as databricks

        schema_share = databricks.Share("schema_share",
            name="schema_share",
            objects=[{
                "name": "catalog_name.schema_name",
                "data_object_type": "SCHEMA",
                "history_data_sharing_status": "ENABLED",
            }])
        ```

        Creating a Delta Sharing share and share a table with partitions spec and history

        ```python
        import pulumi
        import pulumi_databricks as databricks

        some = databricks.Share("some",
            name="my_share",
            objects=[{
                "name": "my_catalog.my_schema.my_table",
                "data_object_type": "TABLE",
                "history_data_sharing_status": "ENABLED",
                "partitions": [
                    {
                        "values": [
                            {
                                "name": "year",
                                "op": "EQUAL",
                                "value": "2009",
                            },
                            {
                                "name": "month",
                                "op": "EQUAL",
                                "value": "12",
                            },
                        ],
                    },
                    {
                        "values": [{
                            "name": "year",
                            "op": "EQUAL",
                            "value": "2010",
                        }],
                    },
                ],
            }])
        ```

        ## Related Resources

        The following resources are often used in the same context:

        * Recipient to create Delta Sharing recipients.
        * Grants to manage Delta Sharing permissions.
        * get_shares to read existing Delta Sharing shares.

        ## Import

        The share resource can be imported using the name of the share.

        hcl

        import {

          to = databricks_share.this

          id = "<share_name>"

        }

        Alternatively, when using `terraform` version 1.4 or earlier, import using the `pulumi import` command:

        bash

        ```sh
        $ pulumi import databricks:index/share:Share this <share_name>
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[_builtins.str] comment: User-supplied free-form text.
        :param pulumi.Input[_builtins.int] created_at: Time when the share was created.
        :param pulumi.Input[_builtins.str] created_by: The principal that created the share.
        :param pulumi.Input[_builtins.str] name: Name of share. Change forces creation of a new resource.
        :param pulumi.Input[_builtins.str] owner: User name/group name/sp application_id of the share owner.
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: Optional[ShareArgs] = None,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        In Delta Sharing, a share is a read-only collection of tables and table partitions that a provider wants to share with one or more recipients. If your recipient uses a Unity Catalog-enabled Databricks workspace, you can also include notebook files, views (including dynamic views that restrict access at the row and column level), Unity Catalog volumes, and Unity Catalog models in a share.

        > This resource can only be used with a workspace-level provider!

        In a Unity Catalog-enabled Databricks workspace, a share is a securable object registered in Unity Catalog. A `Share` is contained within a databricks_metastore. If you remove a share from your Unity Catalog metastore, all recipients of that share lose the ability to access it.

        ## Example Usage

        > In Pulumi configuration, it is recommended to define objects in alphabetical order of their `name` arguments, so that you get consistent and readable diff. Whenever objects are added or removed, or `name` is renamed, you'll observe a change in the majority of tasks. It's related to the fact that the current version of the provider treats `object` blocks as an ordered list. Alternatively, `object` block could have been an unordered set, though end-users would see the entire block replaced upon a change in single property of the task.

        Creating a Delta Sharing share and add some existing tables to it

        ```python
        import pulumi
        import pulumi_databricks as databricks

        things = databricks.get_tables(catalog_name="sandbox",
            schema_name="things")
        some = databricks.Share("some",
            objects=[{"key": k, "value": v} for k, v in things.ids].apply(lambda entries: [{
                "name": entry["value"],
                "dataObjectType": "TABLE",
            } for entry in entries]),
            name="my_share")
        ```

        Creating a Delta Sharing share and add a schema to it(including all current and future tables).

        ```python
        import pulumi
        import pulumi_databricks as databricks

        schema_share = databricks.Share("schema_share",
            name="schema_share",
            objects=[{
                "name": "catalog_name.schema_name",
                "data_object_type": "SCHEMA",
                "history_data_sharing_status": "ENABLED",
            }])
        ```

        Creating a Delta Sharing share and share a table with partitions spec and history

        ```python
        import pulumi
        import pulumi_databricks as databricks

        some = databricks.Share("some",
            name="my_share",
            objects=[{
                "name": "my_catalog.my_schema.my_table",
                "data_object_type": "TABLE",
                "history_data_sharing_status": "ENABLED",
                "partitions": [
                    {
                        "values": [
                            {
                                "name": "year",
                                "op": "EQUAL",
                                "value": "2009",
                            },
                            {
                                "name": "month",
                                "op": "EQUAL",
                                "value": "12",
                            },
                        ],
                    },
                    {
                        "values": [{
                            "name": "year",
                            "op": "EQUAL",
                            "value": "2010",
                        }],
                    },
                ],
            }])
        ```

        ## Related Resources

        The following resources are often used in the same context:

        * Recipient to create Delta Sharing recipients.
        * Grants to manage Delta Sharing permissions.
        * get_shares to read existing Delta Sharing shares.

        ## Import

        The share resource can be imported using the name of the share.

        hcl

        import {

          to = databricks_share.this

          id = "<share_name>"

        }

        Alternatively, when using `terraform` version 1.4 or earlier, import using the `pulumi import` command:

        bash

        ```sh
        $ pulumi import databricks:index/share:Share this <share_name>
        ```

        :param str resource_name: The name of the resource.
        :param ShareArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(ShareArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 comment: Optional[pulumi.Input[_builtins.str]] = None,
                 created_at: Optional[pulumi.Input[_builtins.int]] = None,
                 created_by: Optional[pulumi.Input[_builtins.str]] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 objects: Optional[pulumi.Input[Sequence[pulumi.Input[Union['ShareObjectArgs', 'ShareObjectArgsDict']]]]] = None,
                 owner: Optional[pulumi.Input[_builtins.str]] = None,
                 storage_location: Optional[pulumi.Input[_builtins.str]] = None,
                 storage_root: Optional[pulumi.Input[_builtins.str]] = None,
                 updated_at: Optional[pulumi.Input[_builtins.int]] = None,
                 updated_by: Optional[pulumi.Input[_builtins.str]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = ShareArgs.__new__(ShareArgs)

            __props__.__dict__["comment"] = comment
            __props__.__dict__["created_at"] = created_at
            __props__.__dict__["created_by"] = created_by
            __props__.__dict__["name"] = name
            __props__.__dict__["objects"] = objects
            __props__.__dict__["owner"] = owner
            __props__.__dict__["storage_location"] = storage_location
            __props__.__dict__["storage_root"] = storage_root
            __props__.__dict__["updated_at"] = updated_at
            __props__.__dict__["updated_by"] = updated_by
        super(Share, __self__).__init__(
            'databricks:index/share:Share',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            comment: Optional[pulumi.Input[_builtins.str]] = None,
            created_at: Optional[pulumi.Input[_builtins.int]] = None,
            created_by: Optional[pulumi.Input[_builtins.str]] = None,
            name: Optional[pulumi.Input[_builtins.str]] = None,
            objects: Optional[pulumi.Input[Sequence[pulumi.Input[Union['ShareObjectArgs', 'ShareObjectArgsDict']]]]] = None,
            owner: Optional[pulumi.Input[_builtins.str]] = None,
            storage_location: Optional[pulumi.Input[_builtins.str]] = None,
            storage_root: Optional[pulumi.Input[_builtins.str]] = None,
            updated_at: Optional[pulumi.Input[_builtins.int]] = None,
            updated_by: Optional[pulumi.Input[_builtins.str]] = None) -> 'Share':
        """
        Get an existing Share resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[_builtins.str] comment: User-supplied free-form text.
        :param pulumi.Input[_builtins.int] created_at: Time when the share was created.
        :param pulumi.Input[_builtins.str] created_by: The principal that created the share.
        :param pulumi.Input[_builtins.str] name: Name of share. Change forces creation of a new resource.
        :param pulumi.Input[_builtins.str] owner: User name/group name/sp application_id of the share owner.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _ShareState.__new__(_ShareState)

        __props__.__dict__["comment"] = comment
        __props__.__dict__["created_at"] = created_at
        __props__.__dict__["created_by"] = created_by
        __props__.__dict__["name"] = name
        __props__.__dict__["objects"] = objects
        __props__.__dict__["owner"] = owner
        __props__.__dict__["storage_location"] = storage_location
        __props__.__dict__["storage_root"] = storage_root
        __props__.__dict__["updated_at"] = updated_at
        __props__.__dict__["updated_by"] = updated_by
        return Share(resource_name, opts=opts, __props__=__props__)

    @_builtins.property
    @pulumi.getter
    def comment(self) -> pulumi.Output[Optional[_builtins.str]]:
        """
        User-supplied free-form text.
        """
        return pulumi.get(self, "comment")

    @_builtins.property
    @pulumi.getter(name="createdAt")
    def created_at(self) -> pulumi.Output[_builtins.int]:
        """
        Time when the share was created.
        """
        return pulumi.get(self, "created_at")

    @_builtins.property
    @pulumi.getter(name="createdBy")
    def created_by(self) -> pulumi.Output[_builtins.str]:
        """
        The principal that created the share.
        """
        return pulumi.get(self, "created_by")

    @_builtins.property
    @pulumi.getter
    def name(self) -> pulumi.Output[_builtins.str]:
        """
        Name of share. Change forces creation of a new resource.
        """
        return pulumi.get(self, "name")

    @_builtins.property
    @pulumi.getter
    def objects(self) -> pulumi.Output[Optional[Sequence['outputs.ShareObject']]]:
        return pulumi.get(self, "objects")

    @_builtins.property
    @pulumi.getter
    def owner(self) -> pulumi.Output[Optional[_builtins.str]]:
        """
        User name/group name/sp application_id of the share owner.
        """
        return pulumi.get(self, "owner")

    @_builtins.property
    @pulumi.getter(name="storageLocation")
    def storage_location(self) -> pulumi.Output[Optional[_builtins.str]]:
        return pulumi.get(self, "storage_location")

    @_builtins.property
    @pulumi.getter(name="storageRoot")
    def storage_root(self) -> pulumi.Output[Optional[_builtins.str]]:
        return pulumi.get(self, "storage_root")

    @_builtins.property
    @pulumi.getter(name="updatedAt")
    def updated_at(self) -> pulumi.Output[_builtins.int]:
        return pulumi.get(self, "updated_at")

    @_builtins.property
    @pulumi.getter(name="updatedBy")
    def updated_by(self) -> pulumi.Output[_builtins.str]:
        return pulumi.get(self, "updated_by")




# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from . import _utilities

__all__ = ['CleanRoomAutoApprovalRuleArgs', 'CleanRoomAutoApprovalRule']

@pulumi.input_type
class CleanRoomAutoApprovalRuleArgs:
    def __init__(__self__, *,
                 author_collaborator_alias: Optional[pulumi.Input[_builtins.str]] = None,
                 author_scope: Optional[pulumi.Input[_builtins.str]] = None,
                 clean_room_name: Optional[pulumi.Input[_builtins.str]] = None,
                 runner_collaborator_alias: Optional[pulumi.Input[_builtins.str]] = None,
                 workspace_id: Optional[pulumi.Input[_builtins.str]] = None):
        """
        The set of arguments for constructing a CleanRoomAutoApprovalRule resource.
        :param pulumi.Input[_builtins.str] author_collaborator_alias: Collaborator alias of the author covered by the rule.
               Only one of `author_collaborator_alias` and `author_scope` can be set
        :param pulumi.Input[_builtins.str] author_scope: Scope of authors covered by the rule.
               Only one of `author_collaborator_alias` and `author_scope` can be set. Possible values are: `ANY_AUTHOR`
        :param pulumi.Input[_builtins.str] clean_room_name: The name of the clean room this auto-approval rule belongs to
        :param pulumi.Input[_builtins.str] runner_collaborator_alias: Collaborator alias of the runner covered by the rule
        :param pulumi.Input[_builtins.str] workspace_id: Workspace ID of the resource
        """
        if author_collaborator_alias is not None:
            pulumi.set(__self__, "author_collaborator_alias", author_collaborator_alias)
        if author_scope is not None:
            pulumi.set(__self__, "author_scope", author_scope)
        if clean_room_name is not None:
            pulumi.set(__self__, "clean_room_name", clean_room_name)
        if runner_collaborator_alias is not None:
            pulumi.set(__self__, "runner_collaborator_alias", runner_collaborator_alias)
        if workspace_id is not None:
            pulumi.set(__self__, "workspace_id", workspace_id)

    @_builtins.property
    @pulumi.getter(name="authorCollaboratorAlias")
    def author_collaborator_alias(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Collaborator alias of the author covered by the rule.
        Only one of `author_collaborator_alias` and `author_scope` can be set
        """
        return pulumi.get(self, "author_collaborator_alias")

    @author_collaborator_alias.setter
    def author_collaborator_alias(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "author_collaborator_alias", value)

    @_builtins.property
    @pulumi.getter(name="authorScope")
    def author_scope(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Scope of authors covered by the rule.
        Only one of `author_collaborator_alias` and `author_scope` can be set. Possible values are: `ANY_AUTHOR`
        """
        return pulumi.get(self, "author_scope")

    @author_scope.setter
    def author_scope(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "author_scope", value)

    @_builtins.property
    @pulumi.getter(name="cleanRoomName")
    def clean_room_name(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The name of the clean room this auto-approval rule belongs to
        """
        return pulumi.get(self, "clean_room_name")

    @clean_room_name.setter
    def clean_room_name(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "clean_room_name", value)

    @_builtins.property
    @pulumi.getter(name="runnerCollaboratorAlias")
    def runner_collaborator_alias(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Collaborator alias of the runner covered by the rule
        """
        return pulumi.get(self, "runner_collaborator_alias")

    @runner_collaborator_alias.setter
    def runner_collaborator_alias(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "runner_collaborator_alias", value)

    @_builtins.property
    @pulumi.getter(name="workspaceId")
    def workspace_id(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Workspace ID of the resource
        """
        return pulumi.get(self, "workspace_id")

    @workspace_id.setter
    def workspace_id(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "workspace_id", value)


@pulumi.input_type
class _CleanRoomAutoApprovalRuleState:
    def __init__(__self__, *,
                 author_collaborator_alias: Optional[pulumi.Input[_builtins.str]] = None,
                 author_scope: Optional[pulumi.Input[_builtins.str]] = None,
                 clean_room_name: Optional[pulumi.Input[_builtins.str]] = None,
                 created_at: Optional[pulumi.Input[_builtins.int]] = None,
                 rule_id: Optional[pulumi.Input[_builtins.str]] = None,
                 rule_owner_collaborator_alias: Optional[pulumi.Input[_builtins.str]] = None,
                 runner_collaborator_alias: Optional[pulumi.Input[_builtins.str]] = None,
                 workspace_id: Optional[pulumi.Input[_builtins.str]] = None):
        """
        Input properties used for looking up and filtering CleanRoomAutoApprovalRule resources.
        :param pulumi.Input[_builtins.str] author_collaborator_alias: Collaborator alias of the author covered by the rule.
               Only one of `author_collaborator_alias` and `author_scope` can be set
        :param pulumi.Input[_builtins.str] author_scope: Scope of authors covered by the rule.
               Only one of `author_collaborator_alias` and `author_scope` can be set. Possible values are: `ANY_AUTHOR`
        :param pulumi.Input[_builtins.str] clean_room_name: The name of the clean room this auto-approval rule belongs to
        :param pulumi.Input[_builtins.int] created_at: (integer) - Timestamp of when the rule was created, in epoch milliseconds
        :param pulumi.Input[_builtins.str] rule_id: (string) - A generated UUID identifying the rule
        :param pulumi.Input[_builtins.str] rule_owner_collaborator_alias: (string) - The owner of the rule to whom the rule applies
        :param pulumi.Input[_builtins.str] runner_collaborator_alias: Collaborator alias of the runner covered by the rule
        :param pulumi.Input[_builtins.str] workspace_id: Workspace ID of the resource
        """
        if author_collaborator_alias is not None:
            pulumi.set(__self__, "author_collaborator_alias", author_collaborator_alias)
        if author_scope is not None:
            pulumi.set(__self__, "author_scope", author_scope)
        if clean_room_name is not None:
            pulumi.set(__self__, "clean_room_name", clean_room_name)
        if created_at is not None:
            pulumi.set(__self__, "created_at", created_at)
        if rule_id is not None:
            pulumi.set(__self__, "rule_id", rule_id)
        if rule_owner_collaborator_alias is not None:
            pulumi.set(__self__, "rule_owner_collaborator_alias", rule_owner_collaborator_alias)
        if runner_collaborator_alias is not None:
            pulumi.set(__self__, "runner_collaborator_alias", runner_collaborator_alias)
        if workspace_id is not None:
            pulumi.set(__self__, "workspace_id", workspace_id)

    @_builtins.property
    @pulumi.getter(name="authorCollaboratorAlias")
    def author_collaborator_alias(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Collaborator alias of the author covered by the rule.
        Only one of `author_collaborator_alias` and `author_scope` can be set
        """
        return pulumi.get(self, "author_collaborator_alias")

    @author_collaborator_alias.setter
    def author_collaborator_alias(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "author_collaborator_alias", value)

    @_builtins.property
    @pulumi.getter(name="authorScope")
    def author_scope(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Scope of authors covered by the rule.
        Only one of `author_collaborator_alias` and `author_scope` can be set. Possible values are: `ANY_AUTHOR`
        """
        return pulumi.get(self, "author_scope")

    @author_scope.setter
    def author_scope(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "author_scope", value)

    @_builtins.property
    @pulumi.getter(name="cleanRoomName")
    def clean_room_name(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The name of the clean room this auto-approval rule belongs to
        """
        return pulumi.get(self, "clean_room_name")

    @clean_room_name.setter
    def clean_room_name(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "clean_room_name", value)

    @_builtins.property
    @pulumi.getter(name="createdAt")
    def created_at(self) -> Optional[pulumi.Input[_builtins.int]]:
        """
        (integer) - Timestamp of when the rule was created, in epoch milliseconds
        """
        return pulumi.get(self, "created_at")

    @created_at.setter
    def created_at(self, value: Optional[pulumi.Input[_builtins.int]]):
        pulumi.set(self, "created_at", value)

    @_builtins.property
    @pulumi.getter(name="ruleId")
    def rule_id(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        (string) - A generated UUID identifying the rule
        """
        return pulumi.get(self, "rule_id")

    @rule_id.setter
    def rule_id(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "rule_id", value)

    @_builtins.property
    @pulumi.getter(name="ruleOwnerCollaboratorAlias")
    def rule_owner_collaborator_alias(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        (string) - The owner of the rule to whom the rule applies
        """
        return pulumi.get(self, "rule_owner_collaborator_alias")

    @rule_owner_collaborator_alias.setter
    def rule_owner_collaborator_alias(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "rule_owner_collaborator_alias", value)

    @_builtins.property
    @pulumi.getter(name="runnerCollaboratorAlias")
    def runner_collaborator_alias(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Collaborator alias of the runner covered by the rule
        """
        return pulumi.get(self, "runner_collaborator_alias")

    @runner_collaborator_alias.setter
    def runner_collaborator_alias(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "runner_collaborator_alias", value)

    @_builtins.property
    @pulumi.getter(name="workspaceId")
    def workspace_id(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Workspace ID of the resource
        """
        return pulumi.get(self, "workspace_id")

    @workspace_id.setter
    def workspace_id(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "workspace_id", value)


@pulumi.type_token("databricks:index/cleanRoomAutoApprovalRule:CleanRoomAutoApprovalRule")
class CleanRoomAutoApprovalRule(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 author_collaborator_alias: Optional[pulumi.Input[_builtins.str]] = None,
                 author_scope: Optional[pulumi.Input[_builtins.str]] = None,
                 clean_room_name: Optional[pulumi.Input[_builtins.str]] = None,
                 runner_collaborator_alias: Optional[pulumi.Input[_builtins.str]] = None,
                 workspace_id: Optional[pulumi.Input[_builtins.str]] = None,
                 __props__=None):
        """
        ## Import

        As of Pulumi v1.5, resources can be imported through configuration.

        hcl

        import {

          id = "rule_id"

          to = databricks_clean_room_auto_approval_rule.this

        }

        If you are using an older version of Pulumi, import the resource using the `pulumi import` command as follows:

        ```sh
        $ pulumi import databricks:index/cleanRoomAutoApprovalRule:CleanRoomAutoApprovalRule databricks_clean_room_auto_approval_rule "rule_id"
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[_builtins.str] author_collaborator_alias: Collaborator alias of the author covered by the rule.
               Only one of `author_collaborator_alias` and `author_scope` can be set
        :param pulumi.Input[_builtins.str] author_scope: Scope of authors covered by the rule.
               Only one of `author_collaborator_alias` and `author_scope` can be set. Possible values are: `ANY_AUTHOR`
        :param pulumi.Input[_builtins.str] clean_room_name: The name of the clean room this auto-approval rule belongs to
        :param pulumi.Input[_builtins.str] runner_collaborator_alias: Collaborator alias of the runner covered by the rule
        :param pulumi.Input[_builtins.str] workspace_id: Workspace ID of the resource
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: Optional[CleanRoomAutoApprovalRuleArgs] = None,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        ## Import

        As of Pulumi v1.5, resources can be imported through configuration.

        hcl

        import {

          id = "rule_id"

          to = databricks_clean_room_auto_approval_rule.this

        }

        If you are using an older version of Pulumi, import the resource using the `pulumi import` command as follows:

        ```sh
        $ pulumi import databricks:index/cleanRoomAutoApprovalRule:CleanRoomAutoApprovalRule databricks_clean_room_auto_approval_rule "rule_id"
        ```

        :param str resource_name: The name of the resource.
        :param CleanRoomAutoApprovalRuleArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(CleanRoomAutoApprovalRuleArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 author_collaborator_alias: Optional[pulumi.Input[_builtins.str]] = None,
                 author_scope: Optional[pulumi.Input[_builtins.str]] = None,
                 clean_room_name: Optional[pulumi.Input[_builtins.str]] = None,
                 runner_collaborator_alias: Optional[pulumi.Input[_builtins.str]] = None,
                 workspace_id: Optional[pulumi.Input[_builtins.str]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = CleanRoomAutoApprovalRuleArgs.__new__(CleanRoomAutoApprovalRuleArgs)

            __props__.__dict__["author_collaborator_alias"] = author_collaborator_alias
            __props__.__dict__["author_scope"] = author_scope
            __props__.__dict__["clean_room_name"] = clean_room_name
            __props__.__dict__["runner_collaborator_alias"] = runner_collaborator_alias
            __props__.__dict__["workspace_id"] = workspace_id
            __props__.__dict__["created_at"] = None
            __props__.__dict__["rule_id"] = None
            __props__.__dict__["rule_owner_collaborator_alias"] = None
        super(CleanRoomAutoApprovalRule, __self__).__init__(
            'databricks:index/cleanRoomAutoApprovalRule:CleanRoomAutoApprovalRule',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            author_collaborator_alias: Optional[pulumi.Input[_builtins.str]] = None,
            author_scope: Optional[pulumi.Input[_builtins.str]] = None,
            clean_room_name: Optional[pulumi.Input[_builtins.str]] = None,
            created_at: Optional[pulumi.Input[_builtins.int]] = None,
            rule_id: Optional[pulumi.Input[_builtins.str]] = None,
            rule_owner_collaborator_alias: Optional[pulumi.Input[_builtins.str]] = None,
            runner_collaborator_alias: Optional[pulumi.Input[_builtins.str]] = None,
            workspace_id: Optional[pulumi.Input[_builtins.str]] = None) -> 'CleanRoomAutoApprovalRule':
        """
        Get an existing CleanRoomAutoApprovalRule resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[_builtins.str] author_collaborator_alias: Collaborator alias of the author covered by the rule.
               Only one of `author_collaborator_alias` and `author_scope` can be set
        :param pulumi.Input[_builtins.str] author_scope: Scope of authors covered by the rule.
               Only one of `author_collaborator_alias` and `author_scope` can be set. Possible values are: `ANY_AUTHOR`
        :param pulumi.Input[_builtins.str] clean_room_name: The name of the clean room this auto-approval rule belongs to
        :param pulumi.Input[_builtins.int] created_at: (integer) - Timestamp of when the rule was created, in epoch milliseconds
        :param pulumi.Input[_builtins.str] rule_id: (string) - A generated UUID identifying the rule
        :param pulumi.Input[_builtins.str] rule_owner_collaborator_alias: (string) - The owner of the rule to whom the rule applies
        :param pulumi.Input[_builtins.str] runner_collaborator_alias: Collaborator alias of the runner covered by the rule
        :param pulumi.Input[_builtins.str] workspace_id: Workspace ID of the resource
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _CleanRoomAutoApprovalRuleState.__new__(_CleanRoomAutoApprovalRuleState)

        __props__.__dict__["author_collaborator_alias"] = author_collaborator_alias
        __props__.__dict__["author_scope"] = author_scope
        __props__.__dict__["clean_room_name"] = clean_room_name
        __props__.__dict__["created_at"] = created_at
        __props__.__dict__["rule_id"] = rule_id
        __props__.__dict__["rule_owner_collaborator_alias"] = rule_owner_collaborator_alias
        __props__.__dict__["runner_collaborator_alias"] = runner_collaborator_alias
        __props__.__dict__["workspace_id"] = workspace_id
        return CleanRoomAutoApprovalRule(resource_name, opts=opts, __props__=__props__)

    @_builtins.property
    @pulumi.getter(name="authorCollaboratorAlias")
    def author_collaborator_alias(self) -> pulumi.Output[Optional[_builtins.str]]:
        """
        Collaborator alias of the author covered by the rule.
        Only one of `author_collaborator_alias` and `author_scope` can be set
        """
        return pulumi.get(self, "author_collaborator_alias")

    @_builtins.property
    @pulumi.getter(name="authorScope")
    def author_scope(self) -> pulumi.Output[Optional[_builtins.str]]:
        """
        Scope of authors covered by the rule.
        Only one of `author_collaborator_alias` and `author_scope` can be set. Possible values are: `ANY_AUTHOR`
        """
        return pulumi.get(self, "author_scope")

    @_builtins.property
    @pulumi.getter(name="cleanRoomName")
    def clean_room_name(self) -> pulumi.Output[Optional[_builtins.str]]:
        """
        The name of the clean room this auto-approval rule belongs to
        """
        return pulumi.get(self, "clean_room_name")

    @_builtins.property
    @pulumi.getter(name="createdAt")
    def created_at(self) -> pulumi.Output[_builtins.int]:
        """
        (integer) - Timestamp of when the rule was created, in epoch milliseconds
        """
        return pulumi.get(self, "created_at")

    @_builtins.property
    @pulumi.getter(name="ruleId")
    def rule_id(self) -> pulumi.Output[_builtins.str]:
        """
        (string) - A generated UUID identifying the rule
        """
        return pulumi.get(self, "rule_id")

    @_builtins.property
    @pulumi.getter(name="ruleOwnerCollaboratorAlias")
    def rule_owner_collaborator_alias(self) -> pulumi.Output[_builtins.str]:
        """
        (string) - The owner of the rule to whom the rule applies
        """
        return pulumi.get(self, "rule_owner_collaborator_alias")

    @_builtins.property
    @pulumi.getter(name="runnerCollaboratorAlias")
    def runner_collaborator_alias(self) -> pulumi.Output[Optional[_builtins.str]]:
        """
        Collaborator alias of the runner covered by the rule
        """
        return pulumi.get(self, "runner_collaborator_alias")

    @_builtins.property
    @pulumi.getter(name="workspaceId")
    def workspace_id(self) -> pulumi.Output[Optional[_builtins.str]]:
        """
        Workspace ID of the resource
        """
        return pulumi.get(self, "workspace_id")




# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from . import _utilities
from . import outputs
from ._inputs import *

__all__ = [
    'GetCleanRoomAssetRevisionsCleanRoomAssetResult',
    'AwaitableGetCleanRoomAssetRevisionsCleanRoomAssetResult',
    'get_clean_room_asset_revisions_clean_room_asset',
    'get_clean_room_asset_revisions_clean_room_asset_output',
]

@pulumi.output_type
class GetCleanRoomAssetRevisionsCleanRoomAssetResult:
    """
    A collection of values returned by getCleanRoomAssetRevisionsCleanRoomAsset.
    """
    def __init__(__self__, added_at=None, asset_type=None, clean_room_name=None, foreign_table=None, foreign_table_local_details=None, id=None, name=None, notebook=None, owner_collaborator_alias=None, status=None, table=None, table_local_details=None, view=None, view_local_details=None, volume_local_details=None, workspace_id=None):
        if added_at and not isinstance(added_at, int):
            raise TypeError("Expected argument 'added_at' to be a int")
        pulumi.set(__self__, "added_at", added_at)
        if asset_type and not isinstance(asset_type, str):
            raise TypeError("Expected argument 'asset_type' to be a str")
        pulumi.set(__self__, "asset_type", asset_type)
        if clean_room_name and not isinstance(clean_room_name, str):
            raise TypeError("Expected argument 'clean_room_name' to be a str")
        pulumi.set(__self__, "clean_room_name", clean_room_name)
        if foreign_table and not isinstance(foreign_table, dict):
            raise TypeError("Expected argument 'foreign_table' to be a dict")
        pulumi.set(__self__, "foreign_table", foreign_table)
        if foreign_table_local_details and not isinstance(foreign_table_local_details, dict):
            raise TypeError("Expected argument 'foreign_table_local_details' to be a dict")
        pulumi.set(__self__, "foreign_table_local_details", foreign_table_local_details)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if name and not isinstance(name, str):
            raise TypeError("Expected argument 'name' to be a str")
        pulumi.set(__self__, "name", name)
        if notebook and not isinstance(notebook, dict):
            raise TypeError("Expected argument 'notebook' to be a dict")
        pulumi.set(__self__, "notebook", notebook)
        if owner_collaborator_alias and not isinstance(owner_collaborator_alias, str):
            raise TypeError("Expected argument 'owner_collaborator_alias' to be a str")
        pulumi.set(__self__, "owner_collaborator_alias", owner_collaborator_alias)
        if status and not isinstance(status, str):
            raise TypeError("Expected argument 'status' to be a str")
        pulumi.set(__self__, "status", status)
        if table and not isinstance(table, dict):
            raise TypeError("Expected argument 'table' to be a dict")
        pulumi.set(__self__, "table", table)
        if table_local_details and not isinstance(table_local_details, dict):
            raise TypeError("Expected argument 'table_local_details' to be a dict")
        pulumi.set(__self__, "table_local_details", table_local_details)
        if view and not isinstance(view, dict):
            raise TypeError("Expected argument 'view' to be a dict")
        pulumi.set(__self__, "view", view)
        if view_local_details and not isinstance(view_local_details, dict):
            raise TypeError("Expected argument 'view_local_details' to be a dict")
        pulumi.set(__self__, "view_local_details", view_local_details)
        if volume_local_details and not isinstance(volume_local_details, dict):
            raise TypeError("Expected argument 'volume_local_details' to be a dict")
        pulumi.set(__self__, "volume_local_details", volume_local_details)
        if workspace_id and not isinstance(workspace_id, str):
            raise TypeError("Expected argument 'workspace_id' to be a str")
        pulumi.set(__self__, "workspace_id", workspace_id)

    @_builtins.property
    @pulumi.getter(name="addedAt")
    def added_at(self) -> _builtins.int:
        """
        (integer) - When the asset is added to the clean room, in epoch milliseconds
        """
        return pulumi.get(self, "added_at")

    @_builtins.property
    @pulumi.getter(name="assetType")
    def asset_type(self) -> _builtins.str:
        """
        (string) - The type of the asset. Possible values are: `FOREIGN_TABLE`, `NOTEBOOK_FILE`, `TABLE`, `VIEW`, `VOLUME`
        """
        return pulumi.get(self, "asset_type")

    @_builtins.property
    @pulumi.getter(name="cleanRoomName")
    def clean_room_name(self) -> Optional[_builtins.str]:
        """
        (string) - The name of the clean room this asset belongs to.
        This field is required for create operations and populated by the server for responses
        """
        return pulumi.get(self, "clean_room_name")

    @_builtins.property
    @pulumi.getter(name="foreignTable")
    def foreign_table(self) -> Optional['outputs.GetCleanRoomAssetRevisionsCleanRoomAssetForeignTableResult']:
        """
        (CleanRoomAssetForeignTable) - Foreign table details available to all collaborators of the clean room.
        Present if and only if **asset_type** is **FOREIGN_TABLE**
        """
        return pulumi.get(self, "foreign_table")

    @_builtins.property
    @pulumi.getter(name="foreignTableLocalDetails")
    def foreign_table_local_details(self) -> Optional['outputs.GetCleanRoomAssetRevisionsCleanRoomAssetForeignTableLocalDetailsResult']:
        """
        (CleanRoomAssetForeignTableLocalDetails) - Local details for a foreign that are only available to its owner.
        Present if and only if **asset_type** is **FOREIGN_TABLE**
        """
        return pulumi.get(self, "foreign_table_local_details")

    @_builtins.property
    @pulumi.getter
    def id(self) -> _builtins.str:
        """
        The provider-assigned unique ID for this managed resource.
        """
        return pulumi.get(self, "id")

    @_builtins.property
    @pulumi.getter
    def name(self) -> _builtins.str:
        """
        (string) - The name of the partition column
        """
        return pulumi.get(self, "name")

    @_builtins.property
    @pulumi.getter
    def notebook(self) -> Optional['outputs.GetCleanRoomAssetRevisionsCleanRoomAssetNotebookResult']:
        """
        (CleanRoomAssetNotebook) - Notebook details available to all collaborators of the clean room.
        Present if and only if **asset_type** is **NOTEBOOK_FILE**
        """
        return pulumi.get(self, "notebook")

    @_builtins.property
    @pulumi.getter(name="ownerCollaboratorAlias")
    def owner_collaborator_alias(self) -> _builtins.str:
        """
        (string) - The alias of the collaborator who owns this asset
        """
        return pulumi.get(self, "owner_collaborator_alias")

    @_builtins.property
    @pulumi.getter
    def status(self) -> _builtins.str:
        """
        (string) - Status of the asset. Possible values are: `ACTIVE`, `PENDING`, `PERMISSION_DENIED`
        """
        return pulumi.get(self, "status")

    @_builtins.property
    @pulumi.getter
    def table(self) -> Optional['outputs.GetCleanRoomAssetRevisionsCleanRoomAssetTableResult']:
        """
        (CleanRoomAssetTable) - Table details available to all collaborators of the clean room.
        Present if and only if **asset_type** is **TABLE**
        """
        return pulumi.get(self, "table")

    @_builtins.property
    @pulumi.getter(name="tableLocalDetails")
    def table_local_details(self) -> Optional['outputs.GetCleanRoomAssetRevisionsCleanRoomAssetTableLocalDetailsResult']:
        """
        (CleanRoomAssetTableLocalDetails) - Local details for a table that are only available to its owner.
        Present if and only if **asset_type** is **TABLE**
        """
        return pulumi.get(self, "table_local_details")

    @_builtins.property
    @pulumi.getter
    def view(self) -> Optional['outputs.GetCleanRoomAssetRevisionsCleanRoomAssetViewResult']:
        """
        (CleanRoomAssetView) - View details available to all collaborators of the clean room.
        Present if and only if **asset_type** is **VIEW**
        """
        return pulumi.get(self, "view")

    @_builtins.property
    @pulumi.getter(name="viewLocalDetails")
    def view_local_details(self) -> Optional['outputs.GetCleanRoomAssetRevisionsCleanRoomAssetViewLocalDetailsResult']:
        """
        (CleanRoomAssetViewLocalDetails) - Local details for a view that are only available to its owner.
        Present if and only if **asset_type** is **VIEW**
        """
        return pulumi.get(self, "view_local_details")

    @_builtins.property
    @pulumi.getter(name="volumeLocalDetails")
    def volume_local_details(self) -> Optional['outputs.GetCleanRoomAssetRevisionsCleanRoomAssetVolumeLocalDetailsResult']:
        """
        (CleanRoomAssetVolumeLocalDetails) - Local details for a volume that are only available to its owner.
        Present if and only if **asset_type** is **VOLUME**
        """
        return pulumi.get(self, "volume_local_details")

    @_builtins.property
    @pulumi.getter(name="workspaceId")
    def workspace_id(self) -> Optional[_builtins.str]:
        return pulumi.get(self, "workspace_id")


class AwaitableGetCleanRoomAssetRevisionsCleanRoomAssetResult(GetCleanRoomAssetRevisionsCleanRoomAssetResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetCleanRoomAssetRevisionsCleanRoomAssetResult(
            added_at=self.added_at,
            asset_type=self.asset_type,
            clean_room_name=self.clean_room_name,
            foreign_table=self.foreign_table,
            foreign_table_local_details=self.foreign_table_local_details,
            id=self.id,
            name=self.name,
            notebook=self.notebook,
            owner_collaborator_alias=self.owner_collaborator_alias,
            status=self.status,
            table=self.table,
            table_local_details=self.table_local_details,
            view=self.view,
            view_local_details=self.view_local_details,
            volume_local_details=self.volume_local_details,
            workspace_id=self.workspace_id)


def get_clean_room_asset_revisions_clean_room_asset(asset_type: Optional[_builtins.str] = None,
                                                    clean_room_name: Optional[_builtins.str] = None,
                                                    foreign_table: Optional[Union['GetCleanRoomAssetRevisionsCleanRoomAssetForeignTableArgs', 'GetCleanRoomAssetRevisionsCleanRoomAssetForeignTableArgsDict']] = None,
                                                    foreign_table_local_details: Optional[Union['GetCleanRoomAssetRevisionsCleanRoomAssetForeignTableLocalDetailsArgs', 'GetCleanRoomAssetRevisionsCleanRoomAssetForeignTableLocalDetailsArgsDict']] = None,
                                                    name: Optional[_builtins.str] = None,
                                                    notebook: Optional[Union['GetCleanRoomAssetRevisionsCleanRoomAssetNotebookArgs', 'GetCleanRoomAssetRevisionsCleanRoomAssetNotebookArgsDict']] = None,
                                                    table: Optional[Union['GetCleanRoomAssetRevisionsCleanRoomAssetTableArgs', 'GetCleanRoomAssetRevisionsCleanRoomAssetTableArgsDict']] = None,
                                                    table_local_details: Optional[Union['GetCleanRoomAssetRevisionsCleanRoomAssetTableLocalDetailsArgs', 'GetCleanRoomAssetRevisionsCleanRoomAssetTableLocalDetailsArgsDict']] = None,
                                                    view: Optional[Union['GetCleanRoomAssetRevisionsCleanRoomAssetViewArgs', 'GetCleanRoomAssetRevisionsCleanRoomAssetViewArgsDict']] = None,
                                                    view_local_details: Optional[Union['GetCleanRoomAssetRevisionsCleanRoomAssetViewLocalDetailsArgs', 'GetCleanRoomAssetRevisionsCleanRoomAssetViewLocalDetailsArgsDict']] = None,
                                                    volume_local_details: Optional[Union['GetCleanRoomAssetRevisionsCleanRoomAssetVolumeLocalDetailsArgs', 'GetCleanRoomAssetRevisionsCleanRoomAssetVolumeLocalDetailsArgsDict']] = None,
                                                    workspace_id: Optional[_builtins.str] = None,
                                                    opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetCleanRoomAssetRevisionsCleanRoomAssetResult:
    """
    Use this data source to access information about an existing resource.

    :param _builtins.str asset_type: (string) - The type of the asset. Possible values are: `FOREIGN_TABLE`, `NOTEBOOK_FILE`, `TABLE`, `VIEW`, `VOLUME`
    :param _builtins.str clean_room_name: (string) - The name of the clean room this asset belongs to.
           This field is required for create operations and populated by the server for responses
    :param Union['GetCleanRoomAssetRevisionsCleanRoomAssetForeignTableArgs', 'GetCleanRoomAssetRevisionsCleanRoomAssetForeignTableArgsDict'] foreign_table: (CleanRoomAssetForeignTable) - Foreign table details available to all collaborators of the clean room.
           Present if and only if **asset_type** is **FOREIGN_TABLE**
    :param Union['GetCleanRoomAssetRevisionsCleanRoomAssetForeignTableLocalDetailsArgs', 'GetCleanRoomAssetRevisionsCleanRoomAssetForeignTableLocalDetailsArgsDict'] foreign_table_local_details: (CleanRoomAssetForeignTableLocalDetails) - Local details for a foreign that are only available to its owner.
           Present if and only if **asset_type** is **FOREIGN_TABLE**
    :param _builtins.str name: A fully qualified name that uniquely identifies the asset within the clean room.
           This is also the name displayed in the clean room UI.
           
           For UC securable assets (tables, volumes, etc.), the format is *shared_catalog*.*shared_schema*.*asset_name*
           
           For notebooks, the name is the notebook file name.
           For jar analyses, the name is the jar analysis name
    :param Union['GetCleanRoomAssetRevisionsCleanRoomAssetNotebookArgs', 'GetCleanRoomAssetRevisionsCleanRoomAssetNotebookArgsDict'] notebook: (CleanRoomAssetNotebook) - Notebook details available to all collaborators of the clean room.
           Present if and only if **asset_type** is **NOTEBOOK_FILE**
    :param Union['GetCleanRoomAssetRevisionsCleanRoomAssetTableArgs', 'GetCleanRoomAssetRevisionsCleanRoomAssetTableArgsDict'] table: (CleanRoomAssetTable) - Table details available to all collaborators of the clean room.
           Present if and only if **asset_type** is **TABLE**
    :param Union['GetCleanRoomAssetRevisionsCleanRoomAssetTableLocalDetailsArgs', 'GetCleanRoomAssetRevisionsCleanRoomAssetTableLocalDetailsArgsDict'] table_local_details: (CleanRoomAssetTableLocalDetails) - Local details for a table that are only available to its owner.
           Present if and only if **asset_type** is **TABLE**
    :param Union['GetCleanRoomAssetRevisionsCleanRoomAssetViewArgs', 'GetCleanRoomAssetRevisionsCleanRoomAssetViewArgsDict'] view: (CleanRoomAssetView) - View details available to all collaborators of the clean room.
           Present if and only if **asset_type** is **VIEW**
    :param Union['GetCleanRoomAssetRevisionsCleanRoomAssetViewLocalDetailsArgs', 'GetCleanRoomAssetRevisionsCleanRoomAssetViewLocalDetailsArgsDict'] view_local_details: (CleanRoomAssetViewLocalDetails) - Local details for a view that are only available to its owner.
           Present if and only if **asset_type** is **VIEW**
    :param Union['GetCleanRoomAssetRevisionsCleanRoomAssetVolumeLocalDetailsArgs', 'GetCleanRoomAssetRevisionsCleanRoomAssetVolumeLocalDetailsArgsDict'] volume_local_details: (CleanRoomAssetVolumeLocalDetails) - Local details for a volume that are only available to its owner.
           Present if and only if **asset_type** is **VOLUME**
    :param _builtins.str workspace_id: Workspace ID of the resource
    """
    __args__ = dict()
    __args__['assetType'] = asset_type
    __args__['cleanRoomName'] = clean_room_name
    __args__['foreignTable'] = foreign_table
    __args__['foreignTableLocalDetails'] = foreign_table_local_details
    __args__['name'] = name
    __args__['notebook'] = notebook
    __args__['table'] = table
    __args__['tableLocalDetails'] = table_local_details
    __args__['view'] = view
    __args__['viewLocalDetails'] = view_local_details
    __args__['volumeLocalDetails'] = volume_local_details
    __args__['workspaceId'] = workspace_id
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('databricks:index/getCleanRoomAssetRevisionsCleanRoomAsset:getCleanRoomAssetRevisionsCleanRoomAsset', __args__, opts=opts, typ=GetCleanRoomAssetRevisionsCleanRoomAssetResult).value

    return AwaitableGetCleanRoomAssetRevisionsCleanRoomAssetResult(
        added_at=pulumi.get(__ret__, 'added_at'),
        asset_type=pulumi.get(__ret__, 'asset_type'),
        clean_room_name=pulumi.get(__ret__, 'clean_room_name'),
        foreign_table=pulumi.get(__ret__, 'foreign_table'),
        foreign_table_local_details=pulumi.get(__ret__, 'foreign_table_local_details'),
        id=pulumi.get(__ret__, 'id'),
        name=pulumi.get(__ret__, 'name'),
        notebook=pulumi.get(__ret__, 'notebook'),
        owner_collaborator_alias=pulumi.get(__ret__, 'owner_collaborator_alias'),
        status=pulumi.get(__ret__, 'status'),
        table=pulumi.get(__ret__, 'table'),
        table_local_details=pulumi.get(__ret__, 'table_local_details'),
        view=pulumi.get(__ret__, 'view'),
        view_local_details=pulumi.get(__ret__, 'view_local_details'),
        volume_local_details=pulumi.get(__ret__, 'volume_local_details'),
        workspace_id=pulumi.get(__ret__, 'workspace_id'))
def get_clean_room_asset_revisions_clean_room_asset_output(asset_type: Optional[pulumi.Input[_builtins.str]] = None,
                                                           clean_room_name: Optional[pulumi.Input[Optional[_builtins.str]]] = None,
                                                           foreign_table: Optional[pulumi.Input[Optional[Union['GetCleanRoomAssetRevisionsCleanRoomAssetForeignTableArgs', 'GetCleanRoomAssetRevisionsCleanRoomAssetForeignTableArgsDict']]]] = None,
                                                           foreign_table_local_details: Optional[pulumi.Input[Optional[Union['GetCleanRoomAssetRevisionsCleanRoomAssetForeignTableLocalDetailsArgs', 'GetCleanRoomAssetRevisionsCleanRoomAssetForeignTableLocalDetailsArgsDict']]]] = None,
                                                           name: Optional[pulumi.Input[_builtins.str]] = None,
                                                           notebook: Optional[pulumi.Input[Optional[Union['GetCleanRoomAssetRevisionsCleanRoomAssetNotebookArgs', 'GetCleanRoomAssetRevisionsCleanRoomAssetNotebookArgsDict']]]] = None,
                                                           table: Optional[pulumi.Input[Optional[Union['GetCleanRoomAssetRevisionsCleanRoomAssetTableArgs', 'GetCleanRoomAssetRevisionsCleanRoomAssetTableArgsDict']]]] = None,
                                                           table_local_details: Optional[pulumi.Input[Optional[Union['GetCleanRoomAssetRevisionsCleanRoomAssetTableLocalDetailsArgs', 'GetCleanRoomAssetRevisionsCleanRoomAssetTableLocalDetailsArgsDict']]]] = None,
                                                           view: Optional[pulumi.Input[Optional[Union['GetCleanRoomAssetRevisionsCleanRoomAssetViewArgs', 'GetCleanRoomAssetRevisionsCleanRoomAssetViewArgsDict']]]] = None,
                                                           view_local_details: Optional[pulumi.Input[Optional[Union['GetCleanRoomAssetRevisionsCleanRoomAssetViewLocalDetailsArgs', 'GetCleanRoomAssetRevisionsCleanRoomAssetViewLocalDetailsArgsDict']]]] = None,
                                                           volume_local_details: Optional[pulumi.Input[Optional[Union['GetCleanRoomAssetRevisionsCleanRoomAssetVolumeLocalDetailsArgs', 'GetCleanRoomAssetRevisionsCleanRoomAssetVolumeLocalDetailsArgsDict']]]] = None,
                                                           workspace_id: Optional[pulumi.Input[Optional[_builtins.str]]] = None,
                                                           opts: Optional[Union[pulumi.InvokeOptions, pulumi.InvokeOutputOptions]] = None) -> pulumi.Output[GetCleanRoomAssetRevisionsCleanRoomAssetResult]:
    """
    Use this data source to access information about an existing resource.

    :param _builtins.str asset_type: (string) - The type of the asset. Possible values are: `FOREIGN_TABLE`, `NOTEBOOK_FILE`, `TABLE`, `VIEW`, `VOLUME`
    :param _builtins.str clean_room_name: (string) - The name of the clean room this asset belongs to.
           This field is required for create operations and populated by the server for responses
    :param Union['GetCleanRoomAssetRevisionsCleanRoomAssetForeignTableArgs', 'GetCleanRoomAssetRevisionsCleanRoomAssetForeignTableArgsDict'] foreign_table: (CleanRoomAssetForeignTable) - Foreign table details available to all collaborators of the clean room.
           Present if and only if **asset_type** is **FOREIGN_TABLE**
    :param Union['GetCleanRoomAssetRevisionsCleanRoomAssetForeignTableLocalDetailsArgs', 'GetCleanRoomAssetRevisionsCleanRoomAssetForeignTableLocalDetailsArgsDict'] foreign_table_local_details: (CleanRoomAssetForeignTableLocalDetails) - Local details for a foreign that are only available to its owner.
           Present if and only if **asset_type** is **FOREIGN_TABLE**
    :param _builtins.str name: A fully qualified name that uniquely identifies the asset within the clean room.
           This is also the name displayed in the clean room UI.
           
           For UC securable assets (tables, volumes, etc.), the format is *shared_catalog*.*shared_schema*.*asset_name*
           
           For notebooks, the name is the notebook file name.
           For jar analyses, the name is the jar analysis name
    :param Union['GetCleanRoomAssetRevisionsCleanRoomAssetNotebookArgs', 'GetCleanRoomAssetRevisionsCleanRoomAssetNotebookArgsDict'] notebook: (CleanRoomAssetNotebook) - Notebook details available to all collaborators of the clean room.
           Present if and only if **asset_type** is **NOTEBOOK_FILE**
    :param Union['GetCleanRoomAssetRevisionsCleanRoomAssetTableArgs', 'GetCleanRoomAssetRevisionsCleanRoomAssetTableArgsDict'] table: (CleanRoomAssetTable) - Table details available to all collaborators of the clean room.
           Present if and only if **asset_type** is **TABLE**
    :param Union['GetCleanRoomAssetRevisionsCleanRoomAssetTableLocalDetailsArgs', 'GetCleanRoomAssetRevisionsCleanRoomAssetTableLocalDetailsArgsDict'] table_local_details: (CleanRoomAssetTableLocalDetails) - Local details for a table that are only available to its owner.
           Present if and only if **asset_type** is **TABLE**
    :param Union['GetCleanRoomAssetRevisionsCleanRoomAssetViewArgs', 'GetCleanRoomAssetRevisionsCleanRoomAssetViewArgsDict'] view: (CleanRoomAssetView) - View details available to all collaborators of the clean room.
           Present if and only if **asset_type** is **VIEW**
    :param Union['GetCleanRoomAssetRevisionsCleanRoomAssetViewLocalDetailsArgs', 'GetCleanRoomAssetRevisionsCleanRoomAssetViewLocalDetailsArgsDict'] view_local_details: (CleanRoomAssetViewLocalDetails) - Local details for a view that are only available to its owner.
           Present if and only if **asset_type** is **VIEW**
    :param Union['GetCleanRoomAssetRevisionsCleanRoomAssetVolumeLocalDetailsArgs', 'GetCleanRoomAssetRevisionsCleanRoomAssetVolumeLocalDetailsArgsDict'] volume_local_details: (CleanRoomAssetVolumeLocalDetails) - Local details for a volume that are only available to its owner.
           Present if and only if **asset_type** is **VOLUME**
    :param _builtins.str workspace_id: Workspace ID of the resource
    """
    __args__ = dict()
    __args__['assetType'] = asset_type
    __args__['cleanRoomName'] = clean_room_name
    __args__['foreignTable'] = foreign_table
    __args__['foreignTableLocalDetails'] = foreign_table_local_details
    __args__['name'] = name
    __args__['notebook'] = notebook
    __args__['table'] = table
    __args__['tableLocalDetails'] = table_local_details
    __args__['view'] = view
    __args__['viewLocalDetails'] = view_local_details
    __args__['volumeLocalDetails'] = volume_local_details
    __args__['workspaceId'] = workspace_id
    opts = pulumi.InvokeOutputOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke_output('databricks:index/getCleanRoomAssetRevisionsCleanRoomAsset:getCleanRoomAssetRevisionsCleanRoomAsset', __args__, opts=opts, typ=GetCleanRoomAssetRevisionsCleanRoomAssetResult)
    return __ret__.apply(lambda __response__: GetCleanRoomAssetRevisionsCleanRoomAssetResult(
        added_at=pulumi.get(__response__, 'added_at'),
        asset_type=pulumi.get(__response__, 'asset_type'),
        clean_room_name=pulumi.get(__response__, 'clean_room_name'),
        foreign_table=pulumi.get(__response__, 'foreign_table'),
        foreign_table_local_details=pulumi.get(__response__, 'foreign_table_local_details'),
        id=pulumi.get(__response__, 'id'),
        name=pulumi.get(__response__, 'name'),
        notebook=pulumi.get(__response__, 'notebook'),
        owner_collaborator_alias=pulumi.get(__response__, 'owner_collaborator_alias'),
        status=pulumi.get(__response__, 'status'),
        table=pulumi.get(__response__, 'table'),
        table_local_details=pulumi.get(__response__, 'table_local_details'),
        view=pulumi.get(__response__, 'view'),
        view_local_details=pulumi.get(__response__, 'view_local_details'),
        volume_local_details=pulumi.get(__response__, 'volume_local_details'),
        workspace_id=pulumi.get(__response__, 'workspace_id')))



# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from . import _utilities
from . import outputs

__all__ = [
    'GetAlertsV2Result',
    'AwaitableGetAlertsV2Result',
    'get_alerts_v2',
    'get_alerts_v2_output',
]

@pulumi.output_type
class GetAlertsV2Result:
    """
    A collection of values returned by getAlertsV2.
    """
    def __init__(__self__, id=None, results=None, workspace_id=None):
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if results and not isinstance(results, list):
            raise TypeError("Expected argument 'results' to be a list")
        pulumi.set(__self__, "results", results)
        if workspace_id and not isinstance(workspace_id, str):
            raise TypeError("Expected argument 'workspace_id' to be a str")
        pulumi.set(__self__, "workspace_id", workspace_id)

    @_builtins.property
    @pulumi.getter
    def id(self) -> _builtins.str:
        """
        The provider-assigned unique ID for this managed resource.
        """
        return pulumi.get(self, "id")

    @_builtins.property
    @pulumi.getter
    def results(self) -> Sequence['outputs.GetAlertsV2ResultResult']:
        return pulumi.get(self, "results")

    @_builtins.property
    @pulumi.getter(name="workspaceId")
    def workspace_id(self) -> Optional[_builtins.str]:
        return pulumi.get(self, "workspace_id")


class AwaitableGetAlertsV2Result(GetAlertsV2Result):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetAlertsV2Result(
            id=self.id,
            results=self.results,
            workspace_id=self.workspace_id)


def get_alerts_v2(workspace_id: Optional[_builtins.str] = None,
                  opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetAlertsV2Result:
    """
    The SQL Alerts v2 data source allows you to retrieve a list of alerts in Databricks SQL that are accessible to the current user. This data source returns alerts ordered by their creation time.

    You can use this data source to:
    - Get a comprehensive list of all alerts in your workspace
    - Monitor and audit alert configurations across your workspace

    ## Example Usage

    ### List All Alerts
    This example retrieves all alerts accessible to the current user:

    ```python
    import pulumi
    import pulumi_databricks as databricks

    all = databricks.get_alert_v2()
    ```


    :param _builtins.str workspace_id: Workspace ID of the resource
    """
    __args__ = dict()
    __args__['workspaceId'] = workspace_id
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('databricks:index/getAlertsV2:getAlertsV2', __args__, opts=opts, typ=GetAlertsV2Result).value

    return AwaitableGetAlertsV2Result(
        id=pulumi.get(__ret__, 'id'),
        results=pulumi.get(__ret__, 'results'),
        workspace_id=pulumi.get(__ret__, 'workspace_id'))
def get_alerts_v2_output(workspace_id: Optional[pulumi.Input[Optional[_builtins.str]]] = None,
                         opts: Optional[Union[pulumi.InvokeOptions, pulumi.InvokeOutputOptions]] = None) -> pulumi.Output[GetAlertsV2Result]:
    """
    The SQL Alerts v2 data source allows you to retrieve a list of alerts in Databricks SQL that are accessible to the current user. This data source returns alerts ordered by their creation time.

    You can use this data source to:
    - Get a comprehensive list of all alerts in your workspace
    - Monitor and audit alert configurations across your workspace

    ## Example Usage

    ### List All Alerts
    This example retrieves all alerts accessible to the current user:

    ```python
    import pulumi
    import pulumi_databricks as databricks

    all = databricks.get_alert_v2()
    ```


    :param _builtins.str workspace_id: Workspace ID of the resource
    """
    __args__ = dict()
    __args__['workspaceId'] = workspace_id
    opts = pulumi.InvokeOutputOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke_output('databricks:index/getAlertsV2:getAlertsV2', __args__, opts=opts, typ=GetAlertsV2Result)
    return __ret__.apply(lambda __response__: GetAlertsV2Result(
        id=pulumi.get(__response__, 'id'),
        results=pulumi.get(__response__, 'results'),
        workspace_id=pulumi.get(__response__, 'workspace_id')))
